@@ -51,7 +51,9 @@ module FakeFS
     end
 
     class << self
-      alias exists? exist?
+      def identical?(one_path, another_path)
+        FileSystem.find(one_path) == FileSystem.find(another_path)
+      end
 
       # Assume nothing is sticky.
       def sticky?(_path)
@@ -70,7 +72,7 @@ module FakeFS
     end
 
     def self.mtime(path)
-      if exists?(path)
+      if exist?(path)
         FileSystem.find(path).mtime
       else
         raise Errno::ENOENT
@@ -78,7 +80,7 @@ module FakeFS
     end
 
     def self.ctime(path)
-      if exists?(path)
+      if exist?(path)
         FileSystem.find(path).ctime
       else
         raise Errno::ENOENT
@@ -86,7 +88,7 @@ module FakeFS
     end
 
     def self.atime(path)
-      if exists?(path)
+      if exist?(path)
         FileSystem.find(path).atime
       else
         raise Errno::ENOENT
@@ -95,7 +97,7 @@ module FakeFS
 
     def self.utime(atime, mtime, *paths)
       paths.each do |path|
-        if exists?(path)
+        if exist?(path)
           FileSystem.find(path).atime = atime
           FileSystem.find(path).mtime = mtime
         else
@@ -115,11 +117,11 @@ module FakeFS
     end
 
     def self.size?(path)
-      size(path) if exists?(path) && !size(path).zero?
+      size(path) if exist?(path) && !size(path).zero?
     end
 
     def self.zero?(path)
-      exists?(path) && size(path) == 0
+      exist?(path) && size(path) == 0
     end
 
     if RUBY_VERSION >= '2.4'
@@ -170,8 +172,8 @@ module FakeFS
       RealFile.basename(*args)
     end
 
-    def self.dirname(path)
-      RealFile.dirname(path)
+    def self.dirname(*args)
+      RealFile.dirname(*args)
     end
 
     def self.readlink(path)
@@ -193,11 +195,11 @@ module FakeFS
       file.read(length)
     end
 
-    def self.readlines(path)
+    def self.readlines(path, chomp: false)
       file = new(path)
       if file.exists?
         FileSystem.find(path).atime = Time.now
-        file.readlines
+        chomp ? file.readlines.map(&:chomp) : file.readlines
       else
         raise Errno::ENOENT
       end
@@ -227,6 +229,8 @@ module FakeFS
       end
 
       if (target = FileSystem.find(source))
+        return 0 if source == dest
+
         if target.is_a?(FakeFS::FakeSymlink)
           File.symlink(target.target, dest)
         else
@@ -243,8 +247,8 @@ module FakeFS
 
     def self.link(source, dest)
       raise Errno::EPERM, "#{source} or #{dest}" if directory?(source)
-      raise Errno::ENOENT, "#{source} or #{dest}" unless exists?(source)
-      raise Errno::EEXIST, "#{source} or #{dest}" if exists?(dest)
+      raise Errno::ENOENT, "#{source} or #{dest}" unless exist?(source)
+      raise Errno::EEXIST, "#{source} or #{dest}" if exist?(dest)
 
       source = FileSystem.find(source)
       dest = FileSystem.add(dest, source.entry.clone)
@@ -253,14 +257,15 @@ module FakeFS
       0
     end
 
-    def self.delete(*file_names)
-      file_names.each do |file_name|
-        raise Errno::ENOENT, file_name.to_s unless exists?(file_name)
+    def self.delete(*files)
+      files.each do |file|
+        file_name = (file.class == FakeFS::File ? file.path : file.to_s)
+        raise Errno::ENOENT, file_name unless exist?(file_name)
 
         FileUtils.rm(file_name)
       end
 
-      file_names.size
+      files.size
     end
 
     class << self
@@ -324,6 +329,11 @@ module FakeFS
       File.read(file, length, offset, mode: 'rb:ASCII-8BIT')
     end
 
+    def self.binwrite(file, content, offset = nil)
+      mode = offset ? 'r+b:ASCII-8BIT' : 'wb:ASCII-8BIT'
+      File.write(file, content, offset, mode: mode)
+    end
+
     def self.fnmatch?(pattern, path, flags = 0)
       RealFile.fnmatch?(pattern, path, flags)
     end
@@ -562,7 +572,7 @@ module FakeFS
     end
 
     def readpartial(*)
-      raise NotImplementedError
+      super
     end
 
     def atime
@@ -612,7 +622,10 @@ module FakeFS
     end
 
     def binmode?
-      raise NotImplementedError
+      @mode.is_a?(String) && (
+        @mode.include?('b') ||
+        @mode.include?('binary')
+      ) && !@mode.include?('bom')
     end
 
     def close_on_exec=(_bool)
@@ -651,7 +664,7 @@ module FakeFS
 
     def self.write(filename, contents, offset = nil, open_args = {})
       offset, open_args = nil, offset if offset.is_a?(Hash)
-      mode = offset ? 'a' : 'w'
+      mode = offset ? 'r+' : 'w'
       if open_args.any?
         if open_args[:open_args]
           args = [filename, *open_args[:open_args]]
@@ -677,7 +690,7 @@ module FakeFS
     end
 
     def self.birthtime(path)
-      if exists?(path)
+      if exist?(path)
         FileSystem.find(path).birthtime
       else
         raise Errno::ENOENT
@@ -690,7 +703,7 @@ module FakeFS
 
     def read(length = nil, buf = '')
       read_buf = super(length, buf)
-      if binary_mode?
+      if binmode?
         read_buf&.force_encoding('ASCII-8BIT')
       else
         read_buf&.force_encoding(Encoding.default_external)
@@ -857,13 +870,6 @@ module FakeFS
       StringIO.new('', @mode)
     end
 
-    def binary_mode?
-      @mode.is_a?(String) && (
-        @mode.include?('b') ||
-        @mode.include?('binary')
-      ) && !@mode.include?('bom')
-    end
-
     def check_file_existence!
       raise Errno::ENOENT, @path.to_s unless @file
     end
