@@ -3,14 +3,18 @@ module FakeFS
   module FileTest
     extend self
 
-    def exist?(file_name)
-      File.exist?(file_name)
-    end
-
     def directory?(file_name)
       File.directory?(file_name)
     end
 
+    def executable?(file_name)
+      File.executable?(file_name)
+    end
+
+    def exist?(file_name)
+      File.exist?(file_name)
+    end
+
     def file?(file_name)
       File.file?(file_name)
     end
@@ -23,6 +27,22 @@ module FakeFS
       File.readable?(file_name)
     end
 
+    def sticky?(file_name)
+      File.sticky?(file_name)
+    end
+
+    def symlink?(file_name)
+      File.symlink?(file_name)
+    end
+
+    def world_readable?(file_name)
+      File.new(file_name).stat.world_readable?
+    end
+
+    def world_writable?(file_name)
+      File.new(file_name).stat.world_writable?
+    end
+
     def writable?(file_name)
       File.writable?(file_name)
     end
