@@ -18,8 +18,8 @@ module FakeFS
     def self.unhijack!
       captives[:original].each do |name, _prc|
         ::Kernel.send(:remove_method, name.to_sym)
-        ::Kernel.send(:define_method, name.to_sym, proc do |*args, &block|
-          ::FakeFS::Kernel.captives[:original][name].call(*args, &block)
+        ::Kernel.send(:define_method, name.to_sym, proc do |*args, **kwargs, &block|
+          ::FakeFS::Kernel.captives[:original][name].call(*args, **kwargs, &block)
         end)
         ::Kernel.send(:private, name.to_sym)
       end
@@ -32,8 +32,8 @@ module FakeFS
     end
 
     hijack :open do |*args, &block|
-      if args.first.start_with? '|'
-        # This is a system command
+      # This is a system command     or   we're inside IRB internals
+      if args.first.start_with?('|') || self.class.to_s.start_with?("IRB::")
         ::FakeFS::Kernel.captives[:original][:open].call(*args, &block)
       else
         name = args.shift
