@@ -109,10 +109,10 @@ module FakeFS
     if File::ALT_SEPARATOR
       SEPARATOR_LIST = "#{Regexp.quote File::ALT_SEPARATOR}" \
       "#{Regexp.quote File::SEPARATOR}".freeze
-      SEPARATOR_PAT = /[#{SEPARATOR_LIST}]/
+      SEPARATOR_PAT = /[#{SEPARATOR_LIST}]/.freeze
     else
       SEPARATOR_LIST = (Regexp.quote File::SEPARATOR).to_s.freeze
-      SEPARATOR_PAT = /#{Regexp.quote File::SEPARATOR}/
+      SEPARATOR_PAT = /#{Regexp.quote File::SEPARATOR}/.freeze
     end
 
     # Return a pathname which the extension of the basename is substituted by
@@ -442,9 +442,9 @@ module FakeFS
     def chop_basename(path)
       base = File.basename(path)
       if /\A#{SEPARATOR_PAT}?\z/o =~ base
-        return nil
+        nil
       else
-        return path[0, path.rindex(base)], base
+        [path[0, path.rindex(base)], base]
       end
     end
 
@@ -909,11 +909,11 @@ module FakeFS
   # Pathname class
   class Pathname # * Dir *
     # See <tt>Dir.glob</tt>.  Returns or yields Pathname objects.
-    def self.glob(*args) # :yield: pathname
+    def self.glob(*args, **opts) # :yield: pathname
       if block_given?
-        Dir.glob(*args) { |f| yield new(f) }
+        Dir.glob(*args, **opts) { |f| yield new(f) }
       else
-        Dir.glob(*args).map { |f| new(f) }
+        Dir.glob(*args, **opts).map { |f| new(f) }
       end
     end
 
@@ -953,6 +953,14 @@ module FakeFS
     def opendir(&block) # :yield: dir
       Dir.open(@path, &block)
     end
+
+    def glob(pattern, flags = 0)
+      if block_given?
+        Dir.glob(pattern, flags: flags, base: self) { |f| yield join(f) }
+      else
+        Dir.glob(pattern, flags: flags, base: self).map { |f| join(f) }
+      end
+    end
   end
 
   # Pathname class
@@ -1027,6 +1035,6 @@ module FakeFS
 
   # Pathname class
   class Pathname
-    undef =~
+    undef =~ if respond_to?(:=~)
   end
 end
