@@ -1,7 +1,7 @@
-require 'test_helper'
+require_relative '../../test_helper'
 
 # File join test class
-class FileJoin < Minitest::Test
+class FakeFileJoinTest < Minitest::Test
   def setup
     FakeFS.activate!
   end
@@ -11,7 +11,7 @@ class FileJoin < Minitest::Test
   end
 
   [
-    %w(a b),  %w(a/ b), %w(a /b), %w(a/ /b), %w(a / b)
+    ['a', 'b'], ['a/', 'b'], ['a', '/b'], ['a/', '/b'], ['a', '/', 'b']
   ].each_with_index do |args, i|
     define_method "test_file_join_#{i}" do
       assert_equal RealFile.join(args), File.join(args)
