@@ -3,12 +3,9 @@ require_relative 'test_helper'
 # Kernel test class
 class KernelTest < Minitest::Test
   include FakeFS
-  def setup
-    FakeFS.deactivate!
-  end
 
   def teardown
-    FakeFS.activate!
+    FakeFS.deactivate!
   end
 
   def test_can_exec_normally
@@ -54,4 +51,9 @@ class KernelTest < Minitest::Test
     out = open("|echo 'foo'")
     assert_equal "foo\n", out.gets
   end
+
+  def test_kernel_open_can_handle_kwargs_after_deactivation
+    FakeFS.deactivate!
+    open('/dev/null', autoclose: true)
+  end
 end
